Date: 01 4, 2002 12:00:38 PM

# prtree

## Purpose

Look for name anywhere under the node matching rule element number. Print its text to fileName, if found.

## Syntax

prtree(fileName, number, name)

fileName - type: str
number - type: int
name - type: str

## Returns

## Remarks

The output file (fileName) must be set up in advance using openfile, fileout or an output statement.

## Example

## See Also

prchild, prxtree, openfile, fileout, POST Actions